/*-*- mode:C; -*- */
/*
 * Check: a unit test framework for C
 *
 * Copyright (C) 2013 Branden Archer
 * Copyright (C) 2019 Mikko Johannes Koivunalho
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _CHECK_CHECK_STDINT_H
#define _CHECK_CHECK_STDINT_H 1
#ifndef _GENERATED_STDINT_H
#define _GENERATED_STDINT_H "Check 0.15.2"
/* generated using CMake 4.3.0 from file cmake/check_stdint.h.in */

/* Imported CMake variables created during build. */
#define HAVE_STDINT_H 1

#ifdef HAVE_STDINT_H
#define _STDINT_HAVE_STDINT_H 1
#include <stdint.h>
#undef HAVE_STDINT_H
#endif /* defined HAVE_STDINT_H */

/* Define only once */
#endif /* _GENERATED_STDINT_H */
#endif /* _CHECK_CHECK_STDINT_H */
